@@ -1,6 +1,6 @@
 /*
 **********************************************************************
-*   Copyright (C) 2002-2011, International Business Machines
+*   Copyright (C) 2002-2013, International Business Machines
 *   Corporation and others.  All Rights Reserved.
 **********************************************************************
 *   file name:  regex.h
@@ -53,37 +53,20 @@
 
 #include "unicode/uregex.h"
 
+// Forward Declarations
+
 U_NAMESPACE_BEGIN
 
-
-// Forward Declarations...
-
-class RegexMatcher;
-class RegexPattern;
-class UVector;
-class UVector32;
-class UVector64;
-class UnicodeSet;
-struct REStackFrame;
 struct Regex8BitSet;
-class  RuleBasedBreakIterator;
 class  RegexCImpl;
-
-
-
-
-/**
- *   RBBIPatternDump   Debug function, displays the compiled form of a pattern.
- *   @internal
- */
-#ifdef REGEX_DEBUG
-U_INTERNAL void U_EXPORT2
-    RegexPatternDump(const RegexPattern *pat);
-#else
-    #undef RegexPatternDump
-    #define RegexPatternDump(pat)
-#endif
-
+class  RegexMatcher;
+class  RegexPattern;
+struct REStackFrame;
+class  RuleBasedBreakIterator;
+class  UnicodeSet;
+class  UVector;
+class  UVector32;
+class  UVector64;
 
 
 /**
@@ -189,7 +172,6 @@ public:
         UParseError          &pe,
         UErrorCode           &status);
 
-
    /**
     * Compiles the regular expression in string form into a RegexPattern
     * object.  These compile methods, rather than the constructors, are the usual
@@ -214,7 +196,7 @@ public:
     * @param status A reference to a UErrorCode to receive any errors.
     * @return      A regexPattern object for the compiled pattern.
     *
-    * @draft ICU 4.6
+    * @stable ICU 4.6
     */
     static RegexPattern * U_EXPORT2 compile( UText *regex,
         UParseError          &pe,
@@ -248,8 +230,7 @@ public:
         uint32_t             flags,
         UParseError          &pe,
         UErrorCode           &status);
-        
-        
+
    /**
     * Compiles the regular expression in string form into a RegexPattern
     * object using the specified match mode flags.  These compile methods,
@@ -274,13 +255,12 @@ public:
     * @param status   A reference to a UErrorCode to receive any errors.
     * @return      A regexPattern object for the compiled pattern.
     *
-    * @draft ICU 4.6
+    * @stable ICU 4.6
     */
     static RegexPattern * U_EXPORT2 compile( UText *regex,
         uint32_t             flags,
         UParseError          &pe,
         UErrorCode           &status);
-    
 
    /**
     * Compiles the regular expression in string form into a RegexPattern
@@ -308,7 +288,6 @@ public:
         uint32_t             flags,
         UErrorCode           &status);
 
-
    /**
     * Compiles the regular expression in string form into a RegexPattern
     * object using the specified match mode flags.  These compile methods,
@@ -331,12 +310,11 @@ public:
     * @param status   A reference to a UErrorCode to receive any errors.
     * @return      A regexPattern object for the compiled pattern.
     *
-    * @draft ICU 4.6
+    * @stable ICU 4.6
     */
     static RegexPattern * U_EXPORT2 compile( UText *regex,
         uint32_t             flags,
         UErrorCode           &status);
-    
 
    /**
     * Get the match mode flags that were used when compiling this pattern.
@@ -377,7 +355,6 @@ private:
      * or in a UText, using
      * <code>utext_openUChars(UText *ut, const UChar *text, int64_t textLength, UErrorCode *status);</code>
      *
-     * @internal
      */
     RegexMatcher *matcher(const UChar *input,
         UErrorCode          &status) const;
@@ -417,7 +394,6 @@ public:
               UParseError     &pe,
               UErrorCode      &status);
 
-
    /**
     * Test whether a string matches a regular expression.  This convenience function
     * both compiles the regular expression and applies it in a single operation.
@@ -430,14 +406,13 @@ public:
     * @param status A reference to a UErrorCode to receive any errors.
     * @return True if the regular expression exactly matches the full input string.
     *
-    * @draft ICU 4.6
+    * @stable ICU 4.6
     */
     static UBool U_EXPORT2 matches(UText *regex,
         UText           *input,
         UParseError     &pe,
         UErrorCode      &status);
 
-
    /**
     * Returns the regular expression from which this pattern was compiled. This method will work
     * even if the pattern was compiled from a UText.
@@ -457,7 +432,7 @@ public:
     * UText, and that UText was modified, the returned UText may no longer reflect the RegexPattern
     * object.
     *
-    * @draft ICU 4.6
+    * @stable ICU 4.6
     */
     virtual UText *patternText(UErrorCode      &status) const;
 
@@ -542,7 +517,7 @@ public:
      * @param status  A reference to a UErrorCode to receive any errors.
      * @return        The number of destination strings used.  
      *
-     * @draft ICU 4.6
+     * @stable ICU 4.6
      */
     virtual int32_t  split(UText *input,
         UText            *dest[],
@@ -623,11 +598,17 @@ private:
     //
     void        init();            // Common initialization, for use by constructors.
     void        zap();             // Common cleanup
-#ifdef REGEX_DEBUG
-    void        dumpOp(int32_t index) const;
-    friend     void U_EXPORT2 RegexPatternDump(const RegexPattern *);
-#endif
 
+    void        dumpOp(int32_t index) const;
+
+  public:
+#ifndef U_HIDE_INTERNAL_API
+    /**
+      * Dump a compiled pattern. Internal debug function.
+      * @internal
+      */
+    void        dumpPattern() const;
+#endif
 };
 
 
@@ -673,10 +654,10 @@ public:
       *                @see UREGEX_CASE_INSENSITIVE
       *  @param status Any errors are reported by setting this UErrorCode variable.
       *
-      *  @draft ICU 4.6
+      *  @stable ICU 4.6
       */
     RegexMatcher(UText *regexp, uint32_t flags, UErrorCode &status);
-    
+
     /**
       * Construct a RegexMatcher for a regular expression.
       * This is a convenience method that avoids the need to explicitly create
@@ -720,7 +701,7 @@ public:
       *                @see UREGEX_CASE_INSENSITIVE
       *  @param status Any errors are reported by setting this UErrorCode variable.
       *
-      *  @draft ICU 4.6
+      *  @stable ICU 4.6
       */
     RegexMatcher(UText *regexp, UText *input,
         uint32_t flags, UErrorCode &status);
@@ -737,7 +718,6 @@ private:
      * or in a UText, using
      * <code>utext_openUChars(UText *ut, const UChar *text, int64_t textLength, UErrorCode *status);</code>
      *
-     * @internal
      */
     RegexMatcher(const UnicodeString &regexp, const UChar *input,
         uint32_t flags, UErrorCode &status);
@@ -880,7 +860,7 @@ public:
     *                        U_INDEX_OUTOFBOUNDS_ERROR for a bad capture group number.
     *   @return dest if non-NULL, a shallow copy of the input text otherwise
     *
-    *   @draft ICU 4.6
+    *   @stable ICU 4.6
     */
     virtual UText *group(UText *dest, int64_t &group_len, UErrorCode &status) const; 
 
@@ -897,7 +877,7 @@ public:
     *                        U_INDEX_OUTOFBOUNDS_ERROR for a bad capture group number.
     *   @return dest if non-NULL, a shallow copy of the input text otherwise
     *
-    *   @draft ICU 4.6
+    *   @stable ICU 4.6
     */
     virtual UText *group(int32_t groupNum, UText *dest, int64_t &group_len, UErrorCode &status) const;
 
@@ -933,7 +913,7 @@ public:
     *   during the previous match operation.
     *    @param   status      a reference to a UErrorCode to receive any errors.
     *    @return              The (native) position in the input string of the start of the last match.
-    *   @draft ICU 4.6
+    *   @stable ICU 4.6
     */
     virtual int64_t start64(UErrorCode &status) const;
 
@@ -964,7 +944,7 @@ public:
     *                        attempted or the last match failed, and
     *                        U_INDEX_OUTOFBOUNDS_ERROR for a bad capture group number.
     *    @return the (native) start position of substring matched by the specified group.
-    *    @draft ICU 4.6
+    *    @stable ICU 4.6
     */
     virtual int64_t start64(int32_t group, UErrorCode &status) const;
 
@@ -995,7 +975,7 @@ public:
     *                        The index value returned is a native index, corresponding to
     *                        code units for the underlying encoding type, for example,
     *                        a byte index for UTF-8.
-    *   @draft ICU 4.6
+    *   @stable ICU 4.6
     */
     virtual int64_t end64(UErrorCode &status) const;
 
@@ -1034,7 +1014,7 @@ public:
     *              The index value returned is a native index, corresponding to
     *              code units for the underlying encoding type, for example,
     *              a byte index for UTF8.
-    *   @draft ICU 4.6
+    *   @stable ICU 4.6
     */
     virtual int64_t end64(int32_t group, UErrorCode &status) const;
 
@@ -1099,7 +1079,7 @@ public:
     *                until after regexp operations on it are done.
     *   @return this RegexMatcher.
     *
-    *   @draft ICU 4.6
+    *   @stable ICU 4.6
     */
     virtual RegexMatcher &reset(UText *input);
 
@@ -1126,7 +1106,7 @@ public:
     * @param input      The new (moved) text string.
     * @param status     Receives errors detected by this function.
     *
-    * @draft ICU 4.8 
+    * @stable ICU 4.8 
     */
     virtual RegexMatcher &refreshInputText(UText *input, UErrorCode &status);
 
@@ -1142,7 +1122,6 @@ private:
      * or in a UText, using
      * <code>utext_openUChars(UText *ut, const UChar *text, int64_t textLength, UErrorCode *status);</code>
      *
-     * @internal
      */
     RegexMatcher &reset(const UChar *input);
 public:
@@ -1162,7 +1141,7 @@ public:
     *   a UnicodeString.
     *   @return the input text
     *
-    *   @draft ICU 4.6
+    *   @stable ICU 4.6
     */
     virtual UText *inputText() const;
     
@@ -1174,7 +1153,7 @@ public:
     *   @param status error code
     *   @return dest if non-NULL, a shallow copy of the input text otherwise
     *
-    *   @draft ICU 4.6
+    *   @stable ICU 4.6
     */
     virtual UText *getInput(UText *dest, UErrorCode &status) const;
     
@@ -1208,7 +1187,7 @@ public:
      * @param status A reference to a UErrorCode to receive any errors.
      *                If startIndex is not within the specified region bounds, 
      *                U_INDEX_OUTOFBOUNDS_ERROR is returned.
-     * @draft ICU 4.6
+     * @stable ICU 4.6
      */
      virtual RegexMatcher &region(int64_t regionStart, int64_t regionLimit, int64_t startIndex, UErrorCode &status);
 
@@ -1228,7 +1207,7 @@ public:
      * regionEnd (exclusive).
      *
      * @return The starting (native) index of this matcher's region.
-     * @draft ICU 4.6
+     * @stable ICU 4.6
      */
      virtual int64_t regionStart64() const;
 
@@ -1249,7 +1228,7 @@ public:
      * (inclusive) and regionEnd (exclusive).
      *
      * @return The ending point (native) of this matcher's region.
-     * @draft ICU 4.6
+     * @stable ICU 4.6
      */
       virtual int64_t regionEnd64() const;
 
@@ -1310,9 +1289,9 @@ public:
 
 
     /**
-      * Return TRUE if the most recent matching operation touched the
-      *  end of the text being processed.  In this case, additional input text could
-      *  change the results of that match.
+      * Return TRUE if the most recent matching operation attempted to access
+      *  additional input beyond the available input text.
+      *  In this case, additional input text could change the results of the match.
       *
       *  hitEnd() is defined for both successful and unsuccessful matches.
       *  In either case hitEnd() will return TRUE if if the end of the text was
@@ -1380,7 +1359,7 @@ public:
     *    @return              a string containing the results of the find and replace.
     *                          If a pre-allocated UText was provided, it will always be used and returned.
     *
-    *    @draft ICU 4.6
+    *    @stable ICU 4.6
     */
     virtual UText *replaceAll(UText *replacement, UText *dest, UErrorCode &status);
     
@@ -1430,7 +1409,7 @@ public:
     *    @return              a string containing the results of the find and replace.
     *                          If a pre-allocated UText was provided, it will always be used and returned.
     *
-    *    @draft ICU 4.6
+    *    @stable ICU 4.6
     */
     virtual UText *replaceFirst(UText *replacement, UText *dest, UErrorCode &status);
     
@@ -1491,7 +1470,7 @@ public:
     *
     *   @return  this  RegexMatcher
     *
-    *   @draft ICU 4.6
+    *   @stable ICU 4.6
     */
     virtual RegexMatcher &appendReplacement(UText *dest,
         UText *replacement, UErrorCode &status);
@@ -1521,7 +1500,7 @@ public:
     *  @param status error cod
     *  @return  the destination string.
     *
-    *  @draft ICU 4.6
+    *  @stable ICU 4.6
     */
     virtual UText *appendTail(UText *dest, UErrorCode &status);
 
@@ -1576,7 +1555,7 @@ public:
      * @param status  A reference to a UErrorCode to receive any errors.
      * @return        The number of fields into which the input string was split.
      *
-     * @draft ICU 4.6
+     * @stable ICU 4.6
      */
     virtual int32_t  split(UText *input,
         UText           *dest[],
@@ -1691,7 +1670,7 @@ public:
     *                         time the callback function is set will be saved
     *                         and passed to the callback each time that it is called.
     *    @param   status      A reference to a UErrorCode to receive any errors.
-    *    @draft ICU 4.6
+    *    @stable ICU 4.6
     */
     virtual void setFindProgressCallback(URegexFindProgressCallback      *callback,
                                               const void                              *context,
@@ -1706,20 +1685,20 @@ public:
     *    @param   context     Out parameter, receives the user context pointer that
     *                         was set when uregex_setFindProgressCallback() was called.
     *    @param   status      A reference to a UErrorCode to receive any errors.
-    *    @draft ICU 4.6
+    *    @stable ICU 4.6
     */
     virtual void getFindProgressCallback(URegexFindProgressCallback      *&callback,
                                               const void                      *&context,
                                               UErrorCode                      &status);
 
-
+#ifndef U_HIDE_INTERNAL_API
    /**
      *   setTrace   Debug function, enable/disable tracing of the matching engine.
      *              For internal ICU development use only.  DO NO USE!!!!
      *   @internal
      */
     void setTrace(UBool state);
-
+#endif  /* U_HIDE_INTERNAL_API */
 
     /**
     * ICU "poor man's RTTI", returns a UClassID for this class.
@@ -1748,8 +1727,10 @@ private:
     friend class RegexPattern;
     friend class RegexCImpl;
 public:
+#ifndef U_HIDE_INTERNAL_API
     /** @internal  */
     void resetPreserveRegion();  // Reset matcher state, but preserve any region.
+#endif  /* U_HIDE_INTERNAL_API */
 private:
 
     //
@@ -1852,8 +1833,6 @@ private:
                                            //   reported, or that permanently disables this matcher.
 
     RuleBasedBreakIterator  *fWordBreakItr;
-
-
 };
 
 U_NAMESPACE_END
